function [ToF]=tof2(CH2,f,SPW1,SPW2,N,tipo)
%% funcion para calcular el tiempo de vuelo
% CH2 -> señal de recepcion
% f -> frecuencia correspondiente (MHz)
% SPW1 -> inicio de la ventana de la señal de calibración
% SPW2 -> inicio de la ventana de la onda longitudinal
% SPW3 -> inicio de la ventana de la onda transversal
% N -> tamaño en muestras de la ventana
% long -> tiempo de vuelo de la onda longitudinal (s)
% trans -> tiempo de vuelo de la onda longitudinal (s)

%% se carga la señal de calibración para una frecuencia
if tipo=='T'
a=load(strcat('CH2_Freq',num2str(f), 'MHz_CalibracionT_T1A_R1B_U2_Rep1.mat'));
b=load(strcat('CH2_Freq',num2str(f), 'MHz_CalibracionT_T1A_R1B_U2_Rep2.mat'));
c=load(strcat('CH2_Freq',num2str(f), 'MHz_CalibracionT_T1A_R1B_U2_Rep3.mat'));
elseif tipo=='L'
    a=load(strcat('CH2_Freq',num2str(f), 'MHz_CalibracionL_T1A_R1B_U2_Rep1.mat'));
b=load(strcat('CH2_Freq',num2str(f), 'MHz_CalibracionL_T1A_R1B_U2_Rep2.mat'));
c=load(strcat('CH2_Freq',num2str(f), 'MHz_CalibracionL_T1A_R1B_U2_Rep3.mat'));
else
    display('Variable tipo erronea')
end
E=mean([a.signalCH2;b.signalCH2;c.signalCH2]);
%% Se divide la señal en tres bloques
bloque1=E(SPW1:SPW1+N);         % Calibración
bloque2=CH2(SPW2:SPW2+N);       % Onda longitudinal
% bloque3=CH2(SPW3:SPW3+N);       % Onda transversal

%% Se calcula la correlacion de las ondas con la señal de calibracion
y1=xcorr(bloque2,bloque1);          % Correlacion longitudinal-calibracion


%% Maximo de la correlacion (delay entre la señal de calibracion y las ondas)
[~,max2]=max(y1);
% [~,max3]=max(abs(y2));

%% Region donde buscar
WL=N+1;
ToF=((SPW2-SPW1)-(WL-max2))/125e6;                   % ToF longitudinal

